The following tasks implement perceptual paradigms:

- [AntiReach](../envs.md#neurogym.envs.native.antireach.AntiReach)
- [ContextDecisionMaking](../envs.md#neurogym.envs.native.contextdecisionmaking.ContextDecisionMaking)
- [DelayComparison](../envs.md#neurogym.envs.native.delaycomparison.DelayComparison)
- [DelayMatchCategory](../envs.md#neurogym.envs.native.delaymatchcategory.DelayMatchCategory)
- [DelayMatchSample](../envs.md#neurogym.envs.native.delaymatchsample.DelayMatchSample)
- [DelayMatchSampleDistractor1D](../envs.md#neurogym.envs.native.delaymatchsample.DelayMatchSampleDistractor1D)
- [DelayPairedAssociation](../envs.md#neurogym.envs.native.delaypairedassociation.DelayPairedAssociation)
- [DualDelayMatchSample](../envs.md#neurogym.envs.native.dualdelaymatchsample.DualDelayMatchSample)
- [EconomicDecisionMaking](../envs.md#neurogym.envs.native.economicdecisionmaking.EconomicDecisionMaking)
- [HierarchicalReasoning](../envs.md#neurogym.envs.native.hierarchicalreasoning.HierarchicalReasoning)
- [MultiSensoryIntegration](../envs.md#neurogym.envs.native.multisensory.MultiSensoryIntegration)
- [PerceptualDecisionMaking](../envs.md#neurogym.envs.native.perceptualdecisionmaking.PerceptualDecisionMaking)
- [PerceptualDecisionMakingDelayResponse](../envs.md#neurogym.envs.native.perceptualdecisionmaking.PerceptualDecisionMakingDelayResponse)
- [PostDecisionWager](../envs.md#neurogym.envs.native.postdecisionwager.PostDecisionWager)
- [ProbabilisticReasoning](../envs.md#neurogym.envs.native.probabilisticreasoning.ProbabilisticReasoning)
- [PulseDecisionMaking](../envs.md#neurogym.envs.native.perceptualdecisionmaking.PulseDecisionMaking)
- [ReachingDelayResponse](../envs.md#neurogym.envs.native.reachingdelayresponse.ReachingDelayResponse)
- [ContextDecisionMaking](../envs.md#neurogym.envs.native.contextdecisionmaking.ContextDecisionMaking)
